pitcharraytools.pitch_array_row_to_measure
==========================================

.. autofunction:: abjad.tools.pitcharraytools.pitch_array_row_to_measure.pitch_array_row_to_measure
   :noindex:
